@@ -2,23 +2,24 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 15.3.5.4_2-27gs
+es5id: 15.3.5.4_2-45gs
 description: >
     Strict mode - checking access to strict function caller from
-    strict function (FunctionDeclaration defined within an Anonymous
-    FunctionExpression inside strict mode)
-flags: [onlyStrict]
+    non-strict function (FunctionDeclaration with a strict directive
+    prologue defined within an Anonymous FunctionExpression)
+flags: [noStrict]
 ---*/
 
 assert.throws(TypeError, function() {
   (function() {
     function f() {
+      "use strict";
       gNonStrict();
     }
-    f();
+    return f();
   })();
 });
 
 function gNonStrict() {
-  return gNonStrict.caller;
+  return gNonStrict.caller || gNonStrict.caller.throwTypeError;
 }
