@@ -2,18 +2,15 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 8.12.1-1_22
+es5id: 8.12.1-1_4
 description: >
-    Properties - [[HasOwnProperty]] (literal own getter/setter
-    property)
+    Properties - [[HasOwnProperty]] (non-writable, non-configurable,
+    non-enumerable own value property)
 ---*/
 
-var o = {
-  get foo() {
-    return 42;
-  },
-  set foo(x) {;
-  }
-};
+var o = {};
+Object.defineProperty(o, "foo", {
+  value: 42
+});
 
 assert(o.hasOwnProperty("foo"), 'o.hasOwnProperty("foo") !== true');
