@@ -2,10 +2,10 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 15.5.4.20-4-42
+es5id: 15.5.4.20-4-57
 description: >
     String.prototype.trim handles whitepace and lineterminators
-    (ab\uFEFFc)
+    (\u2028\u2028)
 ---*/
 
-assert.sameValue("ab\uFEFFc".trim(), "ab\uFEFFc", '"ab\uFEFFc".trim()');
+assert.sameValue("\u2028\u2028".trim(), "", '"\u2028\u2028".trim()');
