@@ -2,13 +2,13 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 11.13.2-20-s
+es5id: 11.13.2-19-s
 description: >
     ReferenceError isn't thrown if the LeftHandSideExpression of a Compound
-    Assignment operator(&=) evaluates to a resolvable reference
+    Assignment operator(+=) evaluates to a resolvable reference
 ---*/
 
-        var _11_13_2_20 = 5
-        _11_13_2_20 &= 3;
+        var _11_13_2_19 = -1
+        _11_13_2_19 += 10;
 
-assert.sameValue(_11_13_2_20, 1, '_11_13_2_20');
+assert.sameValue(_11_13_2_19, 9, '_11_13_2_19');
