@@ -5,13 +5,11 @@
 info: |
     This test is actually testing the [[Delete]] internal method (8.12.8). Since the
     language provides no way to directly exercise [[Delete]], the tests are placed here.
-es5id: 11.4.1-4.a-15
-description: delete operator returns true when deleting Array expandos
+es5id: 11.4.1-4.a-8
+description: delete operator returns true for built-in objects (JSON)
+flags: [noStrict]
 ---*/
 
-  var a = [1,2,3]
-  a.x = 10;
-  var d = delete a.x;
+var d = delete JSON;
 
 assert.sameValue(d, true, 'd');
-assert.sameValue(a.x, undefined, 'a.x');
