@@ -2,14 +2,14 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 12.2.1-31-s
+es5id: 12.2.1-32-s
 description: >
-    eval as local var identifier defined twice throws SyntaxError in
-    strict mode
+    arguments as local var identifier defined twice and assigned once
+    throws SyntaxError in strict mode
 flags: [onlyStrict]
 ---*/
 
 
 assert.throws(SyntaxError, function() {
-    eval('function foo() { var eval, eval;}');
+    eval('function foo() { var arguments, arguments = 42;}');
 });
